"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
test('Utils-backOff-fail', async (done) => {
    const fn = () => {
        return new Promise((resolve, reject) => {
            reject('rejected');
        });
    };
    utils_1.Utils
        .retry(3, fn, 100)
        .then((result) => {
        fail('Should not revolve! (' + result + ')');
    })
        .catch((error) => {
        expect(error).toEqual('rejected');
        done();
    });
});
test('Utils-backOff-success-first-try', async (done) => {
    const fn = () => {
        return new Promise((resolve, reject) => {
            resolve('success');
        });
    };
    utils_1.Utils
        .retry(3, fn, 100)
        .then((result) => {
        expect(result).toEqual('success');
        done();
    })
        .catch((error) => {
        fail('Should not reject! (' + error + ')');
    });
});
test('Utils-backOff-success-second-try', async (done) => {
    const counterWrapper = { count: 1 };
    const fn = () => {
        return new Promise((resolve, reject) => {
            if (counterWrapper.count === 2) {
                resolve('success');
            }
            else {
                reject('rejected');
                counterWrapper.count++;
            }
        });
    };
    utils_1.Utils
        .retry(3, fn, 100)
        .then((result) => {
        expect(result).toEqual('success');
        expect(counterWrapper.count).toEqual(2);
        done();
    })
        .catch((error) => {
        fail('Should not reject! (' + error + ')');
    });
});
test('Utils-backOff-success-third-try', async (done) => {
    const counterWrapper = { count: 1 };
    const fn = () => {
        return new Promise((resolve, reject) => {
            if (counterWrapper.count === 3) {
                resolve('success');
            }
            else {
                reject('rejected');
                counterWrapper.count++;
            }
        });
    };
    utils_1.Utils
        .retry(3, fn, 100)
        .then((result) => {
        expect(result).toEqual('success');
        expect(counterWrapper.count).toEqual(3);
        done();
    })
        .catch((error) => {
        fail('Should not reject! (' + error + ')');
    });
});
//# sourceMappingURL=utils.test.js.map